==> google_cloud_compute-0.4.1-py2.py3-none-any.whl: google/cloud/compute_v1/services/projects/transports/base.py <==
# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import abc
from typing import Awaitable, Callable, Dict, Optional, Sequence, Union
import packaging.version
import pkg_resources
from requests import __version__ as requests_version

import google.auth  # type: ignore
import google.api_core  # type: ignore
from google.api_core import exceptions as core_exceptions  # type: ignore
from google.api_core import gapic_v1  # type: ignore
from google.api_core import retry as retries  # type: ignore
from google.auth import credentials as ga_credentials  # type: ignore

from google.cloud.compute_v1.types import compute

try:
    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
        gapic_version=pkg_resources.get_distribution("google-cloud-compute",).version,
        grpc_version=None,
        rest_version=requests_version,
    )
except pkg_resources.DistributionNotFound:
    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()

try:
    # google.auth.__version__ was added in 1.26.0
    _GOOGLE_AUTH_VERSION = google.auth.__version__
except AttributeError:
    try:  # try pkg_resources if it is available
        _GOOGLE_AUTH_VERSION = pkg_resources.get_distribution("google-auth").version
    except pkg_resources.DistributionNotFound:  # pragma: NO COVER
        _GOOGLE_AUTH_VERSION = None


class ProjectsTransport(abc.ABC):
    """Abstract transport class for Projects."""

    AUTH_SCOPES = (
        "https://www.googleapis.com/auth/compute",
        "https://www.googleapis.com/auth/cloud-platform",
    )

    DEFAULT_HOST: str = "compute.googleapis.com"

    def __init__(
        self,
        *,
        host: str = DEFAULT_HOST,
        credentials: ga_credentials.Credentials = None,
        credentials_file: Optional[str] = None,
        scopes: Optional[Sequence[str]] = None,
        quota_project_id: Optional[str] = None,
        client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
        **kwargs,
    ) -> None:
        """Instantiate the transport.

        Args:
            host (Optional[str]):
                 The hostname to connect to.
            credentials (Optional[google.auth.credentials.Credentials]): The
                authorization credentials to attach to requests. These
                credentials identify the application to the service; if none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
            credentials_file (Optional[str]): A file with credentials that can
                be loaded with :func:`google.auth.load_credentials_from_file`.
                This argument is mutually exclusive with credentials.
            scopes (Optional[Sequence[str]]): A list of scopes.
            quota_project_id (Optional[str]): An optional project to use for billing
                and quota.
            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
                The client info used to send a user-agent string along with
                API requests. If ``None``, then default info will be used.
                Generally, you only need to set this if you're developing
                your own client library.
        """
        # Save the hostname. Default to port 443 (HTTPS) if none is specified.
        if ":" not in host:
            host += ":443"
        self._host = host

        scopes_kwargs = self._get_scopes_kwargs(self._host, scopes)

        # Save the scopes.
        self._scopes = scopes or self.AUTH_SCOPES

        # If no credentials are provided, then determine the appropriate
        # defaults.
        if credentials and credentials_file:
            raise core_exceptions.DuplicateCredentialArgs(
                "'credentials_file' and 'credentials' are mutually exclusive"
            )

        if credentials_file is not None:
            credentials, _ = google.auth.load_credentials_from_file(
                credentials_file, **scopes_kwargs, quota_project_id=quota_project_id
            )

        elif credentials is None:
            credentials, _ = google.auth.default(
                **scopes_kwargs, quota_project_id=quota_project_id
            )

        # Save the credentials.
        self._credentials = credentials

    # TODO(busunkim): This method is in the base transport
    # to avoid duplicating code across the transport classes. These functions
    # should be deleted once the minimum required versions of google-auth is increased.

    # TODO: Remove this function once google-auth >= 1.25.0 is required
    @classmethod
    def _get_scopes_kwargs(
        cls, host: str, scopes: Optional[Sequence[str]]
    ) -> Dict[str, Optional[Sequence[str]]]:
        """Returns scopes kwargs to pass to google-auth methods depending on the google-auth version"""

        scopes_kwargs = {}

        if _GOOGLE_AUTH_VERSION and (
            packaging.version.parse(_GOOGLE_AUTH_VERSION)
            >= packaging.version.parse("1.25.0")
        ):
            scopes_kwargs = {"scopes": scopes, "default_scopes": cls.AUTH_SCOPES}
        else:
            scopes_kwargs = {"scopes": scopes or cls.AUTH_SCOPES}

        return scopes_kwargs

    def _prep_wrapped_messages(self, client_info):
        # Precompute the wrapped methods.
        self._wrapped_methods = {
            self.disable_xpn_host: gapic_v1.method.wrap_method(
                self.disable_xpn_host, default_timeout=None, client_info=client_info,
            ),
            self.disable_xpn_resource: gapic_v1.method.wrap_method(
                self.disable_xpn_resource,
                default_timeout=None,
                client_info=client_info,
            ),
            self.enable_xpn_host: gapic_v1.method.wrap_method(
                self.enable_xpn_host, default_timeout=None, client_info=client_info,
            ),
            self.enable_xpn_resource: gapic_v1.method.wrap_method(
                self.enable_xpn_resource, default_timeout=None, client_info=client_info,
            ),
            self.get: gapic_v1.method.wrap_method(
                self.get, default_timeout=None, client_info=client_info,
            ),
            self.get_xpn_host: gapic_v1.method.wrap_method(
                self.get_xpn_host, default_timeout=None, client_info=client_info,
            ),
            self.get_xpn_resources: gapic_v1.method.wrap_method(
                self.get_xpn_resources, default_timeout=None, client_info=client_info,
            ),
            self.list_xpn_hosts: gapic_v1.method.wrap_method(
                self.list_xpn_hosts, default_timeout=None, client_info=client_info,
            ),
            self.move_disk: gapic_v1.method.wrap_method(
                self.move_disk, default_timeout=None, client_info=client_info,
            ),
            self.move_instance: gapic_v1.method.wrap_method(
                self.move_instance, default_timeout=None, client_info=client_info,
            ),
            self.set_common_instance_metadata: gapic_v1.method.wrap_method(
                self.set_common_instance_metadata,
                default_timeout=None,
                client_info=client_info,
            ),
            self.set_default_network_tier: gapic_v1.method.wrap_method(
                self.set_default_network_tier,
                default_timeout=None,
                client_info=client_info,
            ),
            self.set_usage_export_bucket: gapic_v1.method.wrap_method(
                self.set_usage_export_bucket,
                default_timeout=None,
                client_info=client_info,
            ),
        }

    @property
    def disable_xpn_host(
        self,
    ) -> Callable[
        [compute.DisableXpnHostProjectRequest],
        Union[compute.Operation, Awaitable[compute.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def disable_xpn_resource(
        self,
    ) -> Callable[
        [compute.DisableXpnResourceProjectRequest],
        Union[compute.Operation, Awaitable[compute.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def enable_xpn_host(
        self,
    ) -> Callable[
        [compute.EnableXpnHostProjectRequest],
        Union[compute.Operation, Awaitable[compute.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def enable_xpn_resource(
        self,
    ) -> Callable[
        [compute.EnableXpnResourceProjectRequest],
        Union[compute.Operation, Awaitable[compute.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def get(
        self,
    ) -> Callable[
        [compute.GetProjectRequest], Union[compute.Project, Awaitable[compute.Project]]
    ]:
        raise NotImplementedError()

    @property
    def get_xpn_host(
        self,
    ) -> Callable[
        [compute.GetXpnHostProjectRequest],
        Union[compute.Project, Awaitable[compute.Project]],
    ]:
        raise NotImplementedError()

    @property
    def get_xpn_resources(
        self,
    ) -> Callable[
        [compute.GetXpnResourcesProjectsRequest],
        Union[
            compute.ProjectsGetXpnResources, Awaitable[compute.ProjectsGetXpnResources]
        ],
    ]:
        raise NotImplementedError()

    @property
    def list_xpn_hosts(
        self,
    ) -> Callable[
        [compute.ListXpnHostsProjectsRequest],
        Union[compute.XpnHostList, Awaitable[compute.XpnHostList]],
    ]:
        raise NotImplementedError()

    @property
    def move_disk(
        self,
    ) -> Callable[
        [compute.MoveDiskProjectRequest],
        Union[compute.Operation, Awaitable[compute.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def move_instance(
        self,
    ) -> Callable[
        [compute.MoveInstanceProjectRequest],
        Union[compute.Operation, Awaitable[compute.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def set_common_instance_metadata(
        self,
    ) -> Callable[
        [compute.SetCommonInstanceMetadataProjectRequest],
        Union[compute.Operation, Awaitable[compute.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def set_default_network_tier(
        self,
    ) -> Callable[
        [compute.SetDefaultNetworkTierProjectRequest],
        Union[compute.Operation, Awaitable[compute.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def set_usage_export_bucket(
        self,
    ) -> Callable[
        [compute.SetUsageExportBucketProjectRequest],
        Union[compute.Operation, Awaitable[compute.Operation]],
    ]:
        raise NotImplementedError()


__all__ = ("ProjectsTransport",)

==> google_cloud_compute-1.16.0-py2.py3-none-any.whl: google/cloud/compute_v1/services/projects/transports/base.py <==
# -*- coding: utf-8 -*-
# Copyright 2023 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import abc
from typing import Awaitable, Callable, Dict, Optional, Sequence, Union

import google.api_core
from google.api_core import exceptions as core_exceptions
from google.api_core import gapic_v1
from google.api_core import retry as retries
import google.auth  # type: ignore
from google.auth import credentials as ga_credentials  # type: ignore
from google.oauth2 import service_account  # type: ignore

from google.cloud.compute_v1 import gapic_version as package_version
from google.cloud.compute_v1.services import global_operations
from google.cloud.compute_v1.types import compute

DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
    gapic_version=package_version.__version__
)


class ProjectsTransport(abc.ABC):
    """Abstract transport class for Projects."""

    AUTH_SCOPES = (
        "https://www.googleapis.com/auth/compute",
        "https://www.googleapis.com/auth/cloud-platform",
    )

    DEFAULT_HOST: str = "compute.googleapis.com"

    def __init__(
        self,
        *,
        host: str = DEFAULT_HOST,
        credentials: Optional[ga_credentials.Credentials] = None,
        credentials_file: Optional[str] = None,
        scopes: Optional[Sequence[str]] = None,
        quota_project_id: Optional[str] = None,
        client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
        always_use_jwt_access: Optional[bool] = False,
        api_audience: Optional[str] = None,
        **kwargs,
    ) -> None:
        """Instantiate the transport.

        Args:
            host (Optional[str]):
                 The hostname to connect to (default: 'compute.googleapis.com').
            credentials (Optional[google.auth.credentials.Credentials]): The
                authorization credentials to attach to requests. These
                credentials identify the application to the service; if none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
            credentials_file (Optional[str]): A file with credentials that can
                be loaded with :func:`google.auth.load_credentials_from_file`.
                This argument is mutually exclusive with credentials.
            scopes (Optional[Sequence[str]]): A list of scopes.
            quota_project_id (Optional[str]): An optional project to use for billing
                and quota.
            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
                The client info used to send a user-agent string along with
                API requests. If ``None``, then default info will be used.
                Generally, you only need to set this if you're developing
                your own client library.
            always_use_jwt_access (Optional[bool]): Whether self signed JWT should
                be used for service account credentials.
        """
        self._extended_operations_services: Dict[str, Any] = {}

        scopes_kwargs = {"scopes": scopes, "default_scopes": self.AUTH_SCOPES}

        # Save the scopes.
        self._scopes = scopes

        # If no credentials are provided, then determine the appropriate
        # defaults.
        if credentials and credentials_file:
            raise core_exceptions.DuplicateCredentialArgs(
                "'credentials_file' and 'credentials' are mutually exclusive"
            )

        if credentials_file is not None:
            credentials, _ = google.auth.load_credentials_from_file(
                credentials_file, **scopes_kwargs, quota_project_id=quota_project_id
            )
        elif credentials is None:
            credentials, _ = google.auth.default(
                **scopes_kwargs, quota_project_id=quota_project_id
            )
            # Don't apply audience if the credentials file passed from user.
            if hasattr(credentials, "with_gdch_audience"):
                credentials = credentials.with_gdch_audience(
                    api_audience if api_audience else host
                )

        # If the credentials are service account credentials, then always try to use self signed JWT.
        if (
            always_use_jwt_access
            and isinstance(credentials, service_account.Credentials)
            and hasattr(service_account.Credentials, "with_always_use_jwt_access")
        ):
            credentials = credentials.with_always_use_jwt_access(True)

        # Save the credentials.
        self._credentials = credentials

        # Save the hostname. Default to port 443 (HTTPS) if none is specified.
        if ":" not in host:
            host += ":443"
        self._host = host

    @property
    def host(self):
        return self._host

    def _prep_wrapped_messages(self, client_info):
        # Precompute the wrapped methods.
        self._wrapped_methods = {
            self.disable_xpn_host: gapic_v1.method.wrap_method(
                self.disable_xpn_host,
                default_timeout=None,
                client_info=client_info,
            ),
            self.disable_xpn_resource: gapic_v1.method.wrap_method(
                self.disable_xpn_resource,
                default_timeout=None,
                client_info=client_info,
            ),
            self.enable_xpn_host: gapic_v1.method.wrap_method(
                self.enable_xpn_host,
                default_timeout=None,
                client_info=client_info,
            ),
            self.enable_xpn_resource: gapic_v1.method.wrap_method(
                self.enable_xpn_resource,
                default_timeout=None,
                client_info=client_info,
            ),
            self.get: gapic_v1.method.wrap_method(
                self.get,
                default_timeout=None,
                client_info=client_info,
            ),
            self.get_xpn_host: gapic_v1.method.wrap_method(
                self.get_xpn_host,
                default_timeout=None,
                client_info=client_info,
            ),
            self.get_xpn_resources: gapic_v1.method.wrap_method(
                self.get_xpn_resources,
                default_timeout=None,
                client_info=client_info,
            ),
            self.list_xpn_hosts: gapic_v1.method.wrap_method(
                self.list_xpn_hosts,
                default_timeout=None,
                client_info=client_info,
            ),
            self.move_disk: gapic_v1.method.wrap_method(
                self.move_disk,
                default_timeout=None,
                client_info=client_info,
            ),
            self.move_instance: gapic_v1.method.wrap_method(
                self.move_instance,
                default_timeout=None,
                client_info=client_info,
            ),
            self.set_common_instance_metadata: gapic_v1.method.wrap_method(
                self.set_common_instance_metadata,
                default_timeout=None,
                client_info=client_info,
            ),
            self.set_default_network_tier: gapic_v1.method.wrap_method(
                self.set_default_network_tier,
                default_timeout=None,
                client_info=client_info,
            ),
            self.set_usage_export_bucket: gapic_v1.method.wrap_method(
                self.set_usage_export_bucket,
                default_timeout=None,
                client_info=client_info,
            ),
        }

    def close(self):
        """Closes resources associated with the transport.

        .. warning::
             Only call this method if the transport is NOT shared
             with other clients - this may cause errors in other clients!
        """
        raise NotImplementedError()

    @property
    def disable_xpn_host(
        self,
    ) -> Callable[
        [compute.DisableXpnHostProjectRequest],
        Union[compute.Operation, Awaitable[compute.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def disable_xpn_resource(
        self,
    ) -> Callable[
        [compute.DisableXpnResourceProjectRequest],
        Union[compute.Operation, Awaitable[compute.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def enable_xpn_host(
        self,
    ) -> Callable[
        [compute.EnableXpnHostProjectRequest],
        Union[compute.Operation, Awaitable[compute.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def enable_xpn_resource(
        self,
    ) -> Callable[
        [compute.EnableXpnResourceProjectRequest],
        Union[compute.Operation, Awaitable[compute.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def get(
        self,
    ) -> Callable[
        [compute.GetProjectRequest], Union[compute.Project, Awaitable[compute.Project]]
    ]:
        raise NotImplementedError()

    @property
    def get_xpn_host(
        self,
    ) -> Callable[
        [compute.GetXpnHostProjectRequest],
        Union[compute.Project, Awaitable[compute.Project]],
    ]:
        raise NotImplementedError()

    @property
    def get_xpn_resources(
        self,
    ) -> Callable[
        [compute.GetXpnResourcesProjectsRequest],
        Union[
            compute.ProjectsGetXpnResources, Awaitable[compute.ProjectsGetXpnResources]
        ],
    ]:
        raise NotImplementedError()

    @property
    def list_xpn_hosts(
        self,
    ) -> Callable[
        [compute.ListXpnHostsProjectsRequest],
        Union[compute.XpnHostList, Awaitable[compute.XpnHostList]],
    ]:
        raise NotImplementedError()

    @property
    def move_disk(
        self,
    ) -> Callable[
        [compute.MoveDiskProjectRequest],
        Union[compute.Operation, Awaitable[compute.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def move_instance(
        self,
    ) -> Callable[
        [compute.MoveInstanceProjectRequest],
        Union[compute.Operation, Awaitable[compute.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def set_common_instance_metadata(
        self,
    ) -> Callable[
        [compute.SetCommonInstanceMetadataProjectRequest],
        Union[compute.Operation, Awaitable[compute.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def set_default_network_tier(
        self,
    ) -> Callable[
        [compute.SetDefaultNetworkTierProjectRequest],
        Union[compute.Operation, Awaitable[compute.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def set_usage_export_bucket(
        self,
    ) -> Callable[
        [compute.SetUsageExportBucketProjectRequest],
        Union[compute.Operation, Awaitable[compute.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def kind(self) -> str:
        raise NotImplementedError()

    @property
    def _global_operations_client(self) -> global_operations.GlobalOperationsClient:
        ex_op_service = self._extended_operations_services.get("global_operations")
        if not ex_op_service:
            ex_op_service = global_operations.GlobalOperationsClient(
                credentials=self._credentials,
                transport=self.kind,
            )
            self._extended_operations_services["global_operations"] = ex_op_service

        return ex_op_service


__all__ = ("ProjectsTransport",)
